Learn R Programming

IPAG (version 0.1.0)

Bosnia: My dataset from CSV

Description

This dataset was imported from a CSV file and included in the IPAG package for demonstration. Data are taken from the article by Augsburg, B., De Haas, R., Harmgart, H., & Meghir, C. (2015). The impacts of microcredit: Evidence from Bosnia and Herzegovina. American Economic Journal: Applied Economics, 7(1), 183-203.

Usage

data(Bosnia)

Arguments

Format

A data frame with the following variables:

Income_0B

Household income for the control group before the experiment

Income_1B

Household income for the treatment group before the experiment

Income_0F

Household income for the control group after the experiment

Income_1F

Household income for the treatment group after the experiment

Details

tools:::Rd_expr_doi("DOI: 10.1257/app.20130272")